//-----------------------------------------------------------------------------
// Title      : bsp_ub022_mk3_ext_lm75
//-----------------------------------------------------------------------------
// Funktion   : Externes TWI-Modul : Temperatur-Sensor
// Schaltung  : myAVR MK3 + myTWI-AddOn-TempSensor
//-----------------------------------------------------------------------------
// Prozessor  : ATMega2560
// Takt       : 16 MHz
// Sprache    : C
// Date       : 20.11.2010
// Version    : 1.1
// Autor      : UB
//-----------------------------------------------------------------------------
#define F_CPU 16000000
#include <avr/io.h>
#include <ub_ext_module/EXT_TWI_LM75.h>
#include <ub_mk3_2560/MK3_2560_LED.h>

//-----------------------------------------------------------------------------
// Hinweis :
// > Quick-Jumper Port-L muss gesetzt sein
// > externes TWI-Modul muss am Stecker rechts unten angeschlossen sein
// > TWI-Port-Pins (D0+D1) werden benoetigt
// > Das LM75 muss auf ADR 90h eingestellt sein			
// - das Programm liest zyklisch den Temperatur Wert und zeigt
//   ihn als Binaerwert an den LEDs an
// - bei einem Fehler wird 0x55 angezeigt
// - bei negativen Temperaturen wird 0xF5 angezeigt
//-----------------------------------------------------------------------------
int main (void)
{
	unsigned int n=0;
	char temperatur=0;

	EXT_INIT_LM75();			// init vom externen Temp-Sensor
	MK3_INIT_LED();				// init der LEDs
	

	while (true)
	{
	    EXT_LM75_READ_TEMP(ADR0_LM75);
	    
	    if(EXT_LM75_OK==true) {
	      // test ob temperatur positiv
	      if(EXT_LM75.negativ==false) {
	        // die Temperatur als Gradwert auslesen
	        temperatur=EXT_LM75.abs_temp;
	        // und per LEDs anzeigen
	        MK3_LED_ZAHL(temperatur);
	      }
	      else {
	        // 0xF5 wird als FEHLER angezeigt
	        MK3_LED_ZAHL(0xF5);	      
	      }
	    }
	    else {
	      // 0x55 wird als FEHLER angezeigt
	      MK3_LED_ZAHL(0x55);	      
	    }
	    
	    for(n=0;n<60000;n++) {
		// kleine Pause
	    }

	}
	return 0;
}
//-----------------------------------------------------------------------------
