//-----------------------------------------------------------------------------
// MK3_2560_LED
// Version 1.2
// 02.11.2011 / UB
// "www.Mikrocontroller-4U.de"
// mc-4u(@)t-online.de
//-----------------------------------------------------------------------------
// Fuer das myAVR MK3 Board
// mit ATMega-2560 @ 16MHz
// LED-Ausgabe
// LEDs an PortL Bit0 bis Bit7
// Quick-Jumper PortL muss gesetzt sein
//-----------------------------------------------------------------------------
// das File muss im Ordner
// "myAVR/WinAVR/AVR/Include/UB_MK3_2560/"
// liegen und mit #include <UB_MK3_2560/MK3_2560_LED.h>
// eingebunden werden
//-----------------------------------------------------------------------------
// Belegt : Port-L (komplett)
//-----------------------------------------------------------------------------


//-----------------------------------------------------------------------------
// Hier koennen Funktionen die nicht benutzt werden
// abgeschaltet werden...einfach den DEFINE von "1" auf "0" aendern
//-----------------------------------------------------------------------------

#define USE_MK3_LED_ON 1
#define USE_MK3_LED_OFF 1
#define USE_MK3_LED_TOGGLE 1
#define USE_MK3_LED_SET 1
#define USE_MK3_LED_ZAHL 1

//-----------------------------------------------------------------------------
// INFOS zur Benutzung :
// 01. Funktion "MK3_INIT_LED" starten
// 02. Funktion "MK3_LED_ON" zum einschalten einer LED
// 03. Funktion "MK3_LED_OFF" zum ausschalten einer LED
// 04. Funktion "MK3_LED_TOGGLE" zum togglen einer LED
// 05. Funktion "MK3_LED_SET" zum ein-/ausschalten einer LED
// 06. Funktion "MK3_LED_ZAHL" zum ausgeben einer Zahl als 8Bit LED
//-----------------------------------------------------------------------------


//-----------------------------------------------------------------------------
// Enumerationen fuer die Funktioen
//-----------------------------------------------------------------------------

typedef enum {
  LED0 = 0,
  LED1,
  LED2,
  LED3,
  LED4,
  LED5,
  LED6,
  LED7,
  LED_ALL
}LEDTYP;


//-----------------------------------------------------------------------------
// Funktionen die vom MAIN benutzt werden koennen
//-----------------------------------------------------------------------------
void MK3_INIT_LED(void);	         // zum initialisieren der LEDs
void MK3_LED_ON(LEDTYP led);	         // zum einschalten von LEDs
void MK3_LED_OFF(LEDTYP led);	         // zum ausschalten von LEDs
void MK3_LED_TOGGLE(LEDTYP led);         // zum togglen von LEDs
void MK3_LED_SET(LEDTYP led, bool wert); // zum ein-ausschalten von LEDs
void MK3_LED_ZAHL(char wert);            // zum anzeigen einer Zahl 




//-----------------------------------------------------------------------------
// Port-Pin definition
//-----------------------------------------------------------------------------
#define MK3_DDR_LED DDRL	// DDR-Register der LEDs
#define MK3_PORT_LED PORTL	// Port der LEDs

#define MK3_LED0 0x01
#define MK3_LED1 0x02
#define MK3_LED2 0x04
#define MK3_LED3 0x08
#define MK3_LED4 0x10
#define MK3_LED5 0x20
#define MK3_LED6 0x40
#define MK3_LED7 0x80

//-----------------------------------------------------------------------------
void MK3_INIT_LED(void) {	// zum initialisieren der LEDs
  // alle LEDs initialisieren
  // als Ausgang
  // alle LEDs AUS
  MK3_DDR_LED = 0xFF;
  MK3_PORT_LED = 0x00; 
}

//-----------------------------------------------------------------------------
#if USE_MK3_LED_ON==1
void MK3_LED_ON(LEDTYP led) {  // zum einschalten von LEDs
  if(led==LED0) MK3_PORT_LED|=MK3_LED0;
  if(led==LED1) MK3_PORT_LED|=MK3_LED1;
  if(led==LED2) MK3_PORT_LED|=MK3_LED2;
  if(led==LED3) MK3_PORT_LED|=MK3_LED3;
  if(led==LED4) MK3_PORT_LED|=MK3_LED4;
  if(led==LED5) MK3_PORT_LED|=MK3_LED5;
  if(led==LED6) MK3_PORT_LED|=MK3_LED6;
  if(led==LED7) MK3_PORT_LED|=MK3_LED7;
  if(led==LED_ALL) MK3_PORT_LED|=0xFF;
}
#endif

//-----------------------------------------------------------------------------
#if USE_MK3_LED_OFF==1
void MK3_LED_OFF(LEDTYP led) {  // zum ausschalten von LEDs
  if(led==LED0) MK3_PORT_LED&=~MK3_LED0;
  if(led==LED1) MK3_PORT_LED&=~MK3_LED1;
  if(led==LED2) MK3_PORT_LED&=~MK3_LED2;
  if(led==LED3) MK3_PORT_LED&=~MK3_LED3;
  if(led==LED4) MK3_PORT_LED&=~MK3_LED4;
  if(led==LED5) MK3_PORT_LED&=~MK3_LED5;
  if(led==LED6) MK3_PORT_LED&=~MK3_LED6;
  if(led==LED7) MK3_PORT_LED&=~MK3_LED7;
  if(led==LED_ALL) MK3_PORT_LED&=~0xFF;
}
#endif

//-----------------------------------------------------------------------------
#if USE_MK3_LED_TOGGLE==1
void MK3_LED_TOGGLE(LEDTYP led) {  // zum togglen von LEDs
  if(led==LED0) MK3_PORT_LED^=MK3_LED0;
  if(led==LED1) MK3_PORT_LED^=MK3_LED1;
  if(led==LED2) MK3_PORT_LED^=MK3_LED2;
  if(led==LED3) MK3_PORT_LED^=MK3_LED3;
  if(led==LED4) MK3_PORT_LED^=MK3_LED4;
  if(led==LED5) MK3_PORT_LED^=MK3_LED5;
  if(led==LED6) MK3_PORT_LED^=MK3_LED6;
  if(led==LED7) MK3_PORT_LED^=MK3_LED7;
  if(led==LED_ALL) MK3_PORT_LED^=0xFF;
}
#endif

//-----------------------------------------------------------------------------
#if USE_MK3_LED_SET==1
void MK3_LED_SET(LEDTYP led, bool wert) { // zum ein-ausschalten von LEDs
  char w=0;

  if(led==LED0) w=MK3_LED0;
  if(led==LED1) w=MK3_LED1;
  if(led==LED2) w=MK3_LED2;
  if(led==LED3) w=MK3_LED3;
  if(led==LED4) w=MK3_LED4;
  if(led==LED5) w=MK3_LED5;
  if(led==LED6) w=MK3_LED6;
  if(led==LED7) w=MK3_LED7;
  if(led==LED_ALL) w=0xFF;

  if(wert==true) {
    MK3_PORT_LED|=w;
  }
  else {
    MK3_PORT_LED&=~w;
  }
}
#endif

//-----------------------------------------------------------------------------
#if USE_MK3_LED_ZAHL==1
void MK3_LED_ZAHL(char wert) {   // zum anzeigen einer Zahl 
  MK3_PORT_LED=wert;
}
#endif






